@@ -23,9 +23,11 @@ import logging
 import itertools
 from collections import OrderedDict
 
+from firepit.query import Aggregation, Group, Query, Table
+
 from kestrel.utils import remove_empty_dicts, dedup_ordered_dicts
 from kestrel.exceptions import *
-from kestrel.semantics import get_entity_table, get_entity_type, get_entity_len
+from kestrel.semantics import get_entity_table, get_entity_type
 from kestrel.symboltable import new_var
 from kestrel.syntax.parser import get_all_input_var_names
 from kestrel.codegen.data import load_data, load_data_file, dump_data_to_file
@@ -72,12 +74,9 @@ def _default_output(func):
 def _guard_empty_input(func):
     @functools.wraps(func)
     def wrapper(stmt, session):
-        input_len_dict = {
-            v: get_entity_len(v, session.symtable)
-            for v in get_all_input_var_names(stmt)
-        }
-        for v, size in input_len_dict.items():
-            if size == 0:
+        for varname in get_all_input_var_names(stmt):
+            v = session.symtable[varname]
+            if v.length + v.records_count == 0:
                 raise EmptyInputVariable(v)
         else:
             return func(stmt, session)
@@ -181,7 +180,7 @@ def info(stmt, session):
 
 @_debug_logger
 def disp(stmt, session):
-    if len(session.symtable[stmt["input"]]) > 0:
+    if session.symtable[stmt["input"]].entity_table:
         content = session.store.lookup(
             get_entity_table(stmt["input"], session.symtable),
             stmt["attrs"],
@@ -480,12 +479,13 @@ def join(stmt, session):
 @_default_output
 @_guard_empty_input
 def group(stmt, session):
-    session.store.assign(
-        stmt["output"],
-        get_entity_table(stmt["input"], session.symtable),
-        op="group",
-        by=stmt["path"],
+    query = Query(
+        [Table(get_entity_table(stmt["input"], session.symtable)), Group(stmt["paths"])]
     )
+    if "aggregations" in stmt:
+        aggs = [(i["func"], i["attr"], i["alias"]) for i in stmt["aggregations"]]
+        query.append(Aggregation(aggs))
+    session.store.assign_query(stmt["output"], query)
 
 
 @_debug_logger
