@@ -56,6 +56,7 @@ import time
 import math
 import lark
 from datetime import datetime
+from contextlib import AbstractContextManager
 
 from kestrel.exceptions import (
     KestrelSyntaxError,
@@ -83,7 +84,7 @@ from kestrel.analytics import AnalyticsManager
 _logger = logging.getLogger(__name__)
 
 
-class Session(object):
+class Session(AbstractContextManager):
     """Kestrel Session class
 
     A session object needs to be instantiated to create a Kestrel runtime space.
@@ -199,7 +200,7 @@ class Session(object):
             tmp_dir = sys_tmp_dir / (
                 self.config["session"]["cache_directory_prefix"] + self.session_id
             )
-            self.runtime_directory = tmp_dir.resolve()
+            self.runtime_directory = tmp_dir.expanduser().resolve()
             if tmp_dir.exists():
                 if tmp_dir.is_dir():
                     _logger.debug(
@@ -239,9 +240,7 @@ class Session(object):
         self.symtable = {}
 
         self.data_source_manager = DataSourceManager(self.config)
-        self.analytics_manager = AnalyticsManager(
-            self.config["language"]["default_analytics_schema"]
-        )
+        self.analytics_manager = AnalyticsManager(self.config)
         iso_ts_regex = r"\d{4}(-\d{2}(-\d{2}(T\d{2}(:\d{2}(:\d{2}Z?)?)?)?)?)?"
         self._iso_ts = re.compile(iso_ts_regex)
 
@@ -475,7 +474,7 @@ class Session(object):
                         stmt, self.data_source_manager.queried_data_sources[-1]
                     )
                 if stmt["command"] == "load" or stmt["command"] == "save":
-                    stmt["path"] = pathlib.Path(stmt["path"]).resolve()
+                    stmt["path"] = pathlib.Path(stmt["path"]).expanduser().resolve()
                 if stmt["command"] == "find":
                     check_semantics_on_find(stmt, self.symtable[stmt["input"]].type)
                 if "attrs" in stmt:
@@ -519,9 +518,6 @@ class Session(object):
 
         return displays
 
-    def __enter__(self):
-        return self
-
     def __exit__(self, exception_type, exception_value, traceback):
         self.close()
 
